@@ -59,8 +59,8 @@ FORMAT_NUMBER_COMMA_SEPARATED2 = '#,##0.00_-'
 FORMAT_PERCENTAGE = BUILTIN_FORMATS[9]
 FORMAT_PERCENTAGE_00 = BUILTIN_FORMATS[10]
 FORMAT_DATE_YYYYMMDD2 = 'yyyy-mm-dd'
-FORMAT_DATE_YYYYMMDD = 'yy-mm-dd'
-FORMAT_DATE_DDMMYYYY = 'dd/mm/yy'
+FORMAT_DATE_YYMMDD = 'yy-mm-dd'
+FORMAT_DATE_DDMMYY = 'dd/mm/yy'
 FORMAT_DATE_DMYSLASH = 'd/m/y'
 FORMAT_DATE_DMYMINUS = 'd-m-y'
 FORMAT_DATE_DMMINUS = 'd-m'
@@ -70,7 +70,7 @@ FORMAT_DATE_XLSX15 = BUILTIN_FORMATS[15]
 FORMAT_DATE_XLSX16 = BUILTIN_FORMATS[16]
 FORMAT_DATE_XLSX17 = BUILTIN_FORMATS[17]
 FORMAT_DATE_XLSX22 = BUILTIN_FORMATS[22]
-FORMAT_DATE_DATETIME = 'd/m/y h:mm'
+FORMAT_DATE_DATETIME = 'yyyy-mm-dd h:mm:ss'
 FORMAT_DATE_TIME1 = BUILTIN_FORMATS[18]
 FORMAT_DATE_TIME2 = BUILTIN_FORMATS[19]
 FORMAT_DATE_TIME3 = BUILTIN_FORMATS[20]
@@ -80,7 +80,7 @@ FORMAT_DATE_TIME6 = BUILTIN_FORMATS[21]
 FORMAT_DATE_TIME7 = 'i:s.S'
 FORMAT_DATE_TIME8 = 'h:mm:ss@'
 FORMAT_DATE_TIMEDELTA = '[hh]:mm:ss'
-FORMAT_DATE_YYYYMMDDSLASH = 'yy/mm/dd@'
+FORMAT_DATE_YYMMDDSLASH = 'yy/mm/dd@'
 FORMAT_CURRENCY_USD_SIMPLE = '"$"#,##0.00_-'
 FORMAT_CURRENCY_USD = '$#,##0_-'
 FORMAT_CURRENCY_EUR_SIMPLE = '[$EUR ]#,##0.00_-'
@@ -101,8 +101,8 @@ class NumberFormat(HashableObject):
     FORMAT_PERCENTAGE = FORMAT_PERCENTAGE
     FORMAT_PERCENTAGE_00 = FORMAT_PERCENTAGE_00
     FORMAT_DATE_YYYYMMDD2 = FORMAT_DATE_YYYYMMDD2
-    FORMAT_DATE_YYYYMMDD = FORMAT_DATE_YYYYMMDD
-    FORMAT_DATE_DDMMYYYY = FORMAT_DATE_DDMMYYYY
+    FORMAT_DATE_YYMMDD = FORMAT_DATE_YYMMDD
+    FORMAT_DATE_DDMMYY = FORMAT_DATE_DDMMYY
     FORMAT_DATE_DMYSLASH = FORMAT_DATE_DMYSLASH
     FORMAT_DATE_DMYMINUS = FORMAT_DATE_DMYMINUS
     FORMAT_DATE_DMMINUS = FORMAT_DATE_DMMINUS
@@ -122,7 +122,7 @@ class NumberFormat(HashableObject):
     FORMAT_DATE_TIME7 = FORMAT_DATE_TIME7
     FORMAT_DATE_TIME8 = FORMAT_DATE_TIME8
     FORMAT_DATE_TIMEDELTA = FORMAT_DATE_TIMEDELTA
-    FORMAT_DATE_YYYYMMDDSLASH = FORMAT_DATE_YYYYMMDDSLASH
+    FORMAT_DATE_YYMMDDSLASH = FORMAT_DATE_YYMMDDSLASH
     FORMAT_CURRENCY_USD_SIMPLE = FORMAT_CURRENCY_USD_SIMPLE
     FORMAT_CURRENCY_USD = FORMAT_CURRENCY_USD
     FORMAT_CURRENCY_EUR_SIMPLE = FORMAT_CURRENCY_EUR_SIMPLE
